package com.sun.tools.jdeps.resources;

public final class version extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "full", "24+36" },
            { "jdk", "24" },
            { "release", "24" },
        };
    }
}
